==> netbeans_6.5.orig.tar.gz: netbeans-6.5/db.metadata.model/test/unit/src/org/netbeans/modules/db/metadata/model/test/api/MetadataTestBase.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.db.metadata.model.test.api;

import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.netbeans.junit.NbTestCase;
import org.netbeans.modules.db.metadata.model.api.MetadataObject;

/**
 *
 * @author Andrei Badea
 */
public class MetadataTestBase extends NbTestCase {

    public MetadataTestBase(String name) {
        super(name);
    }

    public static <T extends MetadataObject> void assertNames(Set<String> names, Collection<T> objects) {
        Set<String> computedNames = new HashSet<String>();
        for (MetadataObject object : objects) {
            computedNames.add(object.getName());
        }
        assertEquals(names, computedNames);
    }

    public static <T extends MetadataObject> void assertNames(List<String> names, Collection<T> objects) {
        assertEquals(names.size(), objects.size());
        int i = 0;
        for (MetadataObject object : objects) {
            assertEquals(names.get(i++), object.getName());
        }
    }
}

==> netbeans_6.7.1.orig.tar.gz: netbeans-6.7.1/db.metadata.model/test/unit/src/org/netbeans/modules/db/metadata/model/test/api/MetadataTestBase.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.db.metadata.model.test.api;

import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.netbeans.junit.NbTestCase;
import org.netbeans.modules.db.metadata.model.api.MetadataElement;

/**
 *
 * @author Andrei Badea
 */
public class MetadataTestBase extends NbTestCase {

    public MetadataTestBase(String name) {
        super(name);
    }

    public static <T extends MetadataElement> void assertNames(Set<String> names, Collection<T> elements) {
        Set<String> computedNames = new HashSet<String>();
        for (MetadataElement element : elements) {
            computedNames.add(element.getName());
        }
        assertEquals(names, computedNames);
    }

    public static <T extends MetadataElement> void assertNames(List<String> names, Collection<T> elements) {
        assertEquals(names.size(), elements.size());
        int i = 0;
        for (MetadataElement element : elements) {
            assertEquals(names.get(i++), element.getName());
        }
    }
}
